==> nextcloud-14.0.1.tgz: nextcloud/lib/l10n/bg.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Неуспешен опит за запис в \"config\" папката!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Това може да бъде решено единствено като разрешиш на уеб сървъра да пише в config папката.",
    "See %s" : "Вижте %s",
    "Sample configuration detected" : "Открита е примерна конфигурация",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Усетено беше че примерната конфигурация е копирана. Това може да развли инсталацията ти и не се поддържа. Моля, прочети документацията преди да правиш промени на config.php",
    "%1$s and %2$s" : "%1$s и %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s и %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s и %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s и %5$s",
    "PHP %s or higher is required." : "Изисква се PHP %s или по-нова.",
    "PHP with a version lower than %s is required." : "Необходим е PHP с версия по-ниска от %s.",
    "Following databases are supported: %s" : "Следните бази данни са поддържани: %s",
    "The command line tool %s could not be found" : "Конзолната команда %s не може да бъде намерена",
    "The library %s is not available." : "Библиотеката %s не е налична",
    "Library %s with a version higher than %s is required - available version %s." : "Необходима е библиотеката %s с версия по-висока от %s - налична версия %s. ",
    "Library %s with a version lower than %s is required - available version %s." : "Необходима е библиотеката %s с версия по-ниска от %s - налична версия %s. ",
    "Following platforms are supported: %s" : "Поддържани са следните платформи: %s",
    "Unknown filetype" : "Непознат тип файл",
    "Invalid image" : "Невалидно изображение.",
    "today" : "днес",
    "yesterday" : "вчера",
    "_%n day ago_::_%n days ago_" : ["преди %n ден","преди %n дни"],
    "last month" : "миналия месец",
    "_%n month ago_::_%n months ago_" : ["преди %n месец","преди %n месеца"],
    "last year" : "миналата година",
    "_%n year ago_::_%n years ago_" : ["преди %n година","преди %n години"],
    "_%n hour ago_::_%n hours ago_" : ["преди %n час","преди %n часа"],
    "_%n minute ago_::_%n minutes ago_" : ["преди %n минута","преди %n минути"],
    "seconds ago" : "преди секунди",
    "File name contains at least one invalid character" : "Името на файла съдържа поне един невалиден символ",
    "File name is too long" : "Името на файла е твърде дълго",
    "__language_name__" : "Български",
    "Help" : "Помощ",
    "Apps" : "Приложения",
    "Users" : "Потребители",
    "Unknown user" : "Непознат потребител",
    "Sharing" : "Споделяне",
    "Additional settings" : "Допълнителни настройки",
    "%s enter the database username and name." : "%s въведете потребителско име и име за базата данни",
    "%s enter the database username." : "%s въведете потребител за базата данни.",
    "%s enter the database name." : "%s въведи име на базата данни.",
    "%s you may not use dots in the database name" : "%s, не може да ползваш точки в името на базата данни.",
    "Oracle username and/or password not valid" : "Невалидно Oracle потребителско име и/или парола.",
    "PostgreSQL username and/or password not valid" : "Невалидно PostgreSQL потребителско име и/или парола.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не се подържа и %s няма да работи правилно на тази платформа. Използвайте го на свой собствен риск!",
    "For the best results, please consider using a GNU/Linux server instead." : "За най-добри резултати, моля, помисли дали не бихте желали да използваште GNU/Linux сървър.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Моля, премахтене настройката за open_basedir от вашия php.ini или преминете към 64-битово PHP.",
    "Set an admin username." : "Задайте потребителско име за администратор.",
    "Set an admin password." : "Задай парола за администратор.",
    "Can't create or write into the data directory %s" : "Неуспешно създаване или записване в \"data\" папката %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Неуспешно споделяне на %s  , защото сървъра не позволява споделяне от тип $i.",
    "Sharing %s failed, because the file does not exist" : "Неуспешно споделяне на %s, защото файлът не съществува.",
    "You are not allowed to share %s" : "Не ти е разрешено да споделяш %s.",
    "Sharing %s failed, because the user %s does not exist" : "Неуспешно споделяне на %s, защото потребител %s не съществува.",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Неуспешно споделяне на %s, защото %s не е член никоя от групите, в които е %s.",
    "Sharing %s failed, because this item is already shared with %s" : "Неуспешно споделяне на %s, защото това съдържание е вече споделено с %s.",
    "Sharing %s failed, because the group %s does not exist" : "Неупешно споделяне на %s, защото групата %s не съществува.",
    "Sharing %s failed, because %s is not a member of the group %s" : "Неуспешно споделяне на %s, защото %s не е член на групата %s.",
    "You need to provide a password to create a public link, only protected links are allowed" : "Трябва да зададеш парола, за да създадеш общодостъпен линк за споделяне, само защитени с пароли линкове са разрешени.",
    "Sharing %s failed, because sharing with links is not allowed" : "Неуспешно споделяне на %s, защото споделянето посредством връзки не е разрешено.",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Неуспешно споделяне на на %s, не може бъде намерено %s. Може би сървъра в момента е недостъпен.",
    "Share type %s is not valid for %s" : "Споделянето на тип %s не валидно за %s.",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Неуспешно задаване на дата на изтичане. Споделни папки или файлове не могат да изтичат по-късно от %s след като са били споделени",
    "Cannot set expiration date. Expiration date is in the past" : "Неуспешно задаване на дата на изтичане. Датата на изтичане е в миналото",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Споделянето на сървърния %s трябва да поддържа OCP\\Share_Backend интерфейс.",
    "Sharing backend %s not found" : "Споделянето на сървърния %s не е открито.",
    "Sharing backend for %s not found" : "Споделянето на сървъра за %s не е открито.",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Неуспешно споделяне на %s, защото промените надвишават правата на достъп дадени на %s.",
    "Sharing %s failed, because resharing is not allowed" : "Неуспешно споделяне на %s, защото повторно споделяне не е разрешено.",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Неуспешно споделяне на %s, защото не е открит първоизточникът на %s, за да бъде споделяне по сървъра.",
    "Sharing %s failed, because the file could not be found in the file cache" : "Неуспешно споделяне на %s, защото файлът не може да бъде намерен в кеша.",
    "%s shared »%s« with you" : "%s сподели »%s« с теб",
    "%s via %s" : "%s чрез %s",
    "Could not find category \"%s\"" : "Невъзможно откриване на категорията \"%s\".",
    "Sunday" : "неделя",
    "Monday" : "понеделник",
    "Tuesday" : "вторник",
    "Wednesday" : "сряда",
    "Thursday" : "четвъртък",
    "Friday" : "петък",
    "Saturday" : "събота",
    "Sun." : "нед",
    "Mon." : "пон",
    "Tue." : "вт",
    "Wed." : "ср",
    "Thu." : "чет",
    "Fri." : "пет",
    "Sat." : "съб",
    "Su" : "нд",
    "Mo" : "пн",
    "We" : "ср",
    "Th" : "чт",
    "Fr" : "пт",
    "Sa" : "сб",
    "January" : "януари",
    "February" : "февруару",
    "March" : "март",
    "April" : "април",
    "May" : "май",
    "June" : "юни",
    "July" : "юли",
    "August" : "август",
    "September" : "септември",
    "October" : "октомври",
    "November" : "ноември",
    "December" : "декември",
    "Jan." : "яну",
    "Feb." : "фев",
    "Mar." : "мар",
    "Apr." : "апр",
    "May." : "май",
    "Jun." : "юни",
    "Jul." : "юли",
    "Aug." : "авг",
    "Sep." : "сеп",
    "Oct." : "окт",
    "Nov." : "ное",
    "Dec." : "дек",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Потребителските имена може да съдържат следните знаци: \"a-z\", \"A-Z\", \"0-9\" и \"_.@-'\"",
    "A valid username must be provided" : "Трябва да въведете валидно потребителско.",
    "Username contains whitespace at the beginning or at the end" : "Потребителското име започва или завършва с интервал.",
    "A valid password must be provided" : "Трябва да въведете валидна парола.",
    "The username is already being used" : "Потребителското име е вече заето.",
    "a safe home for all your data" : "безопасен дом за всички ваши данни",
    "Can't read file" : "Файлът не може да бъде прочетен",
    "Application is not enabled" : "Приложението не е включено",
    "Authentication error" : "Проблем с идентификацията",
    "Token expired. Please reload page." : "Изтекла сесия. Моля, презареди страницата.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Липсват инсталирани драйвери за бази данни(sqlite, mysql или postgresql).",
    "Cannot write into \"config\" directory" : "Неуспешен опит за запис в \"config\" папката.",
    "Cannot write into \"apps\" directory" : "Писането в папка приложения не е възможно",
    "Setting locale to %s failed" : "Неуспешно задаване на %s като настройка език-държава.",
    "Please install one of these locales on your system and restart your webserver." : "Моля, инсталирай едно от следните език-държава на сървъра и рестартирай уеб сървъра.",
    "Please ask your server administrator to install the module." : "Моля, помолете вашия администратор да инсталира модула.",
    "PHP module %s not installed." : "PHP модулът %s не е инсталиран.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Това може да се дължи на cache/accelerator като Zend OPache или eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP модулите са инсталирани, но все още се обявяват като липсващи?",
    "Please ask your server administrator to restart the web server." : "Моля, поискай от своя администратор да рестартира уеб сървъра.",
    "PostgreSQL >= 9 required" : "Изисква се PostgreSQL >= 9",
    "Please upgrade your database version" : "Моля, обнови базата данни.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Моля, променете правата за достъп на 0770, за да не може директорията да бъде видяна от други потребители.",
    "Could not obtain lock type %d on \"%s\"." : "Неуспешен опит за ексклузивен достъп от типa %d върху \"%s\".",
    "APCu" : "APCu",
    "Redis" : "Redis"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5p1.tgz: nextcloud/lib/l10n/bg.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Неуспешен опит за запис в \"config\" папката!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Това може да бъде решено единствено като разрешиш на уеб сървъра да пише в config папката.",
    "See %s" : "Вижте %s",
    "Sample configuration detected" : "Открита е примерна конфигурация",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Усетено беше че примерната конфигурация е копирана. Това може да развли инсталацията ти и не се поддържа. Моля, прочети документацията преди да правиш промени на config.php",
    "%1$s and %2$s" : "%1$s и %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s и %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s и %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s и %5$s",
    "PHP %s or higher is required." : "Изисква се PHP %s или по-нова.",
    "PHP with a version lower than %s is required." : "Необходим е PHP с версия по-ниска от %s.",
    "Following databases are supported: %s" : "Следните бази данни са поддържани: %s",
    "The command line tool %s could not be found" : "Конзолната команда %s не може да бъде намерена",
    "The library %s is not available." : "Библиотеката %s не е налична",
    "Following platforms are supported: %s" : "Поддържани са следните платформи: %s",
    "Unknown filetype" : "Непознат тип файл",
    "Invalid image" : "Невалидно изображение.",
    "today" : "днес",
    "tomorrow" : "утре",
    "yesterday" : "вчера",
    "_%n day ago_::_%n days ago_" : ["преди %n ден","преди %n дни"],
    "next month" : "следващия месец",
    "last month" : "миналия месец",
    "_%n month ago_::_%n months ago_" : ["преди %n месец","преди %n месеца"],
    "next year" : "следващата година",
    "last year" : "миналата година",
    "_%n year ago_::_%n years ago_" : ["преди %n година","преди %n години"],
    "_%n hour ago_::_%n hours ago_" : ["преди %n час","преди %n часа"],
    "_%n minute ago_::_%n minutes ago_" : ["преди %n минута","преди %n минути"],
    "seconds ago" : "преди секунди",
    "File name contains at least one invalid character" : "Името на файла съдържа поне един невалиден символ",
    "File name is too long" : "Името на файла е твърде дълго",
    "__language_name__" : "Български",
    "This is an automatically sent email, please do not reply." : "Имейлът е генериран автоматично, моля не отговаряйте.",
    "Help" : "Помощ",
    "Apps" : "Приложения",
    "Settings" : "Настройки",
    "Log out" : "Отписване",
    "Users" : "Потребители",
    "Unknown user" : "Непознат потребител",
    "Create" : "Създай",
    "Delete" : "Изтриване",
    "Share" : "Споделяне",
    "Basic settings" : "Основни настройки",
    "Sharing" : "Споделяне",
    "Security" : "Сигурност",
    "Additional settings" : "Допълнителни настройки",
    "Personal info" : "Лични данни",
    "Unlimited" : "Неограничено",
    "%s enter the database username and name." : "%s въведете потребителско име и име за базата данни",
    "%s enter the database username." : "%s въведете потребител за базата данни.",
    "%s enter the database name." : "%s въведи име на базата данни.",
    "%s you may not use dots in the database name" : "%s, не може да ползваш точки в името на базата данни.",
    "Oracle username and/or password not valid" : "Невалидно Oracle потребителско име и/или парола.",
    "PostgreSQL username and/or password not valid" : "Невалидно PostgreSQL потребителско име и/или парола.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не се подържа и %s няма да работи правилно на тази платформа. Използвайте го на свой собствен риск!",
    "For the best results, please consider using a GNU/Linux server instead." : "За най-добри резултати, моля, помисли дали не бихте желали да използваште GNU/Linux сървър.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Моля, премахтене настройката за open_basedir от вашия php.ini или преминете към 64-битово PHP.",
    "Set an admin username." : "Задайте потребителско име за администратор.",
    "Set an admin password." : "Задай парола за администратор.",
    "Can't create or write into the data directory %s" : "Неуспешно създаване или записване в \"data\" папката %s",
    "Invalid Federated Cloud ID" : "Невалиден Federated Cloud ID",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Неуспешно споделяне на %s  , защото сървъра не позволява споделяне от тип $i.",
    "Sharing %s failed, because the file does not exist" : "Неуспешно споделяне на %s, защото файлът не съществува.",
    "You are not allowed to share %s" : "Не ти е разрешено да споделяш %s.",
    "You need to provide a password to create a public link, only protected links are allowed" : "Трябва да зададеш парола, за да създадеш общодостъпен линк за споделяне, само защитени с пароли линкове са разрешени.",
    "Sharing %s failed, because sharing with links is not allowed" : "Неуспешно споделяне на %s, защото споделянето посредством връзки не е разрешено.",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Неуспешно задаване на срок на валидност. Споделянията не могат да изтичат по-късно от %s след като са били споделени",
    "Cannot set expiration date. Expiration date is in the past" : "Неуспешно задаване на срок на валидност. Датата на изтичане е в миналото",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Споделянето на сървърния %s трябва да поддържа OCP\\Share_Backend интерфейс.",
    "Sharing backend %s not found" : "Споделянето на сървърния %s не е открито.",
    "Sharing backend for %s not found" : "Споделянето на сървъра за %s не е открито.",
    "Sharing %s failed, because resharing is not allowed" : "Неуспешно споделяне на %s, защото повторното споделяне е забранено",
    "Sharing %s failed, because the file could not be found in the file cache" : "Неуспешно споделяне на %s, защото файлът не може да бъде намерен в кеша.",
    "Can’t set expiration date more than %s days in the future" : "Неуспешно задаване на срок на валидност повече от %s дни в бъдещето",
    "%1$s shared »%2$s« with you" : "%1$s сподели »%2$s« с вас",
    "%1$s shared »%2$s« with you." : "%1$s сподели »%2$s« с вас.",
    "Could not find category \"%s\"" : "Невъзможно откриване на категорията \"%s\".",
    "Sunday" : "неделя",
    "Monday" : "понеделник",
    "Tuesday" : "вторник",
    "Wednesday" : "сряда",
    "Thursday" : "четвъртък",
    "Friday" : "петък",
    "Saturday" : "събота",
    "Sun." : "нед",
    "Mon." : "пон",
    "Tue." : "вт",
    "Wed." : "ср",
    "Thu." : "чет",
    "Fri." : "пет",
    "Sat." : "съб",
    "Su" : "нд",
    "Mo" : "пн",
    "Tu" : "вт",
    "We" : "ср",
    "Th" : "чт",
    "Fr" : "пт",
    "Sa" : "сб",
    "January" : "януари",
    "February" : "февруару",
    "March" : "март",
    "April" : "април",
    "May" : "май",
    "June" : "юни",
    "July" : "юли",
    "August" : "август",
    "September" : "септември",
    "October" : "октомври",
    "November" : "ноември",
    "December" : "декември",
    "Jan." : "яну",
    "Feb." : "фев",
    "Mar." : "мар",
    "Apr." : "апр",
    "May." : "май",
    "Jun." : "юни",
    "Jul." : "юли",
    "Aug." : "авг",
    "Sep." : "сеп",
    "Oct." : "окт",
    "Nov." : "ное",
    "Dec." : "дек",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Потребителските имена може да съдържат следните знаци: \"a-z\", \"A-Z\", \"0-9\" и \"_.@-'\"",
    "A valid username must be provided" : "Трябва да въведете валидно потребителско.",
    "Username contains whitespace at the beginning or at the end" : "Потребителското име започва или завършва с интервал.",
    "A valid password must be provided" : "Трябва да въведете валидна парола.",
    "The username is already being used" : "Потребителското име е вече заето.",
    "User disabled" : "Потребителят е деактивиран",
    "a safe home for all your data" : "безопасен дом за всички ваши данни",
    "Can't read file" : "Файлът не може да бъде прочетен",
    "Application is not enabled" : "Приложението не е включено",
    "Authentication error" : "Грешка при удостоверяването",
    "Token expired. Please reload page." : "Изтекла сесия. Моля, презареди страницата.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Липсват инсталирани драйвери за бази данни(sqlite, mysql или postgresql).",
    "Cannot write into \"config\" directory" : "Неуспешен опит за запис в \"config\" папката.",
    "Cannot write into \"apps\" directory" : "Писането в папка приложения не е възможно",
    "Setting locale to %s failed" : "Неуспешно задаване на %s като настройка език-държава.",
    "Please install one of these locales on your system and restart your webserver." : "Моля, инсталирай едно от следните език-държава на сървъра и рестартирай уеб сървъра.",
    "Please ask your server administrator to install the module." : "Моля, помолете вашия администратор да инсталира модула.",
    "PHP module %s not installed." : "PHP модулът %s не е инсталиран.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Това може да се дължи на cache/accelerator като Zend OPache или eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP модулите са инсталирани, но все още се обявяват като липсващи?",
    "Please ask your server administrator to restart the web server." : "Моля, поискай от своя администратор да рестартира уеб сървъра.",
    "PostgreSQL >= 9 required" : "Изисква се PostgreSQL >= 9",
    "Please upgrade your database version" : "Моля, обнови базата данни.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Моля, променете правата за достъп на 0770, за да не може директорията да бъде видяна от други потребители.",
    "Could not obtain lock type %d on \"%s\"." : "Неуспешен опит за ексклузивен достъп от типa %d върху \"%s\".",
    "Library %s with a version higher than %s is required - available version %s." : "Необходима е библиотеката %s с версия по-висока от %s - налична версия %s. ",
    "Library %s with a version lower than %s is required - available version %s." : "Необходима е библиотеката %s с версия по-ниска от %s - налична версия %s. ",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "Encryption" : "Криптиране",
    "Sync clients" : "Клиенти за синхронизиране",
    "Sharing %s failed, because the user %s does not exist" : "Неуспешно споделяне на %s, защото потребител %s не съществува.",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Неуспешно споделяне на %s, защото %s не е член никоя от групите, в които е %s.",
    "Sharing %s failed, because this item is already shared with %s" : "Неуспешно споделяне на %s, защото това съдържание е вече споделено с %s.",
    "Sharing %s failed, because the group %s does not exist" : "Неупешно споделяне на %s, защото групата %s не съществува.",
    "Sharing %s failed, because %s is not a member of the group %s" : "Неуспешно споделяне на %s, защото %s не е член на групата %s.",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Неуспешно споделяне на на %s, не може бъде намерено %s. Може би сървъра в момента е недостъпен.",
    "Share type %s is not valid for %s" : "Споделянето на тип %s не валидно за %s.",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Неуспешно споделяне на %s, защото промените надвишават правата на достъп дадени на %s.",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Неуспешно споделяне на %s, защото не е открит първоизточникът на %s, за да бъде споделяне по сървъра.",
    "%s shared »%s« with you" : "%s сподели »%s« с вас",
    "%s shared »%s« with you." : "%s сподели »%s« с вас.",
    "%s via %s" : "%s чрез %s"
},
"nplurals=2; plural=(n != 1);");
